package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.QyDjxx;
import java.util.List;

/**
 * 登记信息表Mapper接口
 *
 * @author xxx
 * @date 2019-09-10
 */
public interface QyDjxxMapper
{
    /**
     * 查询登记信息表
     *
     * @param id 登记信息表ID
     * @return 登记信息表
     */
    QyDjxx selectQyDjxxById(Long id);

    /**
     * 查询登记信息表列表
     *
     * @param qyDjxx 登记信息表
     * @return 登记信息表集合
     */
    List<QyDjxx> selectQyDjxxList(QyDjxx qyDjxx);

    /**
     * 新增登记信息表
     *
     * @param qyDjxx 登记信息表
     * @return 结果
     */
    int insertQyDjxx(QyDjxx qyDjxx);

    /**
     * 修改登记信息表
     *
     * @param qyDjxx 登记信息表
     * @return 结果
     */
    int updateQyDjxx(QyDjxx qyDjxx);

    /**
     * 删除登记信息表
     *
     * @param id 登记信息表ID
     * @return 结果
     */
    int deleteQyDjxxById(Long id);

    /**
     * 删除登记信息表
     *
     * @param bsid 登记信息表ID
     * @return 结果
     */
    int deleteQyDjxxByBsId(String bsid);

    /**
     * 批量删除登记信息表
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteQyDjxxByIds(String[] ids);



    QyDjxx selectQyDjxxByBsid(String bsid);

}
